==> helm-annotations-3.4.0-sources.jar: io/dekorate/helm/config/AddIfStatement.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class AddIfStatement{
  public AddIfStatement() {
  }
  public AddIfStatement(String property,String onResourceKind,String onResourceName,Boolean withDefaultValue) {
    this.property = property;
    this.onResourceKind = onResourceKind;
    this.onResourceName = onResourceName;
    this.withDefaultValue = withDefaultValue;
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  public String getProperty() {
    return this.property;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public boolean isWithDefaultValue() {
    return this.withDefaultValue != null &&  this.withDefaultValue;
  }
  public static AddIfStatementBuilder newBuilder() {
    return new AddIfStatementBuilder();
  }
  public static AddIfStatementBuilder newBuilderFromDefaults() {
    return new AddIfStatementBuilder().withWithDefaultValue(true);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddIfStatement that = (AddIfStatement) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (onResourceKind != null ? !onResourceKind.equals(that.onResourceKind) :that.onResourceKind != null) return false;
    if (onResourceName != null ? !onResourceName.equals(that.onResourceName) :that.onResourceName != null) return false;
    if (withDefaultValue != null ? !withDefaultValue.equals(that.withDefaultValue) :that.withDefaultValue != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  super.hashCode());
  }
  
}

==> helm-annotations-3.7.6-sources.jar: io/dekorate/helm/config/AddIfStatement.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class AddIfStatement{
  public AddIfStatement() {
  }
  public AddIfStatement(String property,String onResourceKind,String onResourceName,Boolean withDefaultValue,String description) {
    this.property = property;
    this.onResourceKind = onResourceKind;
    this.onResourceName = onResourceName;
    this.withDefaultValue = withDefaultValue;
    this.description = description;
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  public String getProperty() {
    return this.property;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public boolean isWithDefaultValue() {
    return this.withDefaultValue != null &&  this.withDefaultValue;
  }
  public String getDescription() {
    return this.description;
  }
  public static AddIfStatementBuilder newBuilder() {
    return new AddIfStatementBuilder();
  }
  public static AddIfStatementBuilder newBuilderFromDefaults() {
    return new AddIfStatementBuilder().withWithDefaultValue(true);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddIfStatement that = (AddIfStatement) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (onResourceKind != null ? !onResourceKind.equals(that.onResourceKind) :that.onResourceKind != null) return false;
    if (onResourceName != null ? !onResourceName.equals(that.onResourceName) :that.onResourceName != null) return false;
    if (withDefaultValue != null ? !withDefaultValue.equals(that.withDefaultValue) :that.withDefaultValue != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  
}
